@@ -19,9 +19,13 @@ ASM.yaml      = system.file(package="formods",  "templates",  "ASM.yaml")
 UD.yaml       = system.file(package="formods",  "templates",  "UD.yaml")
 DW.yaml       = system.file(package="formods",  "templates",  "DW.yaml")
 FG.yaml       = system.file(package="formods",  "templates",  "FG.yaml")
-MB.yaml       = system.file(package="ruminate", "templates",  "MB.yaml")
 NCA.yaml      = system.file(package="ruminate", "templates",  "NCA.yaml")
 
+
+# Name of  file to indicate we need to load testing data
+ftmptest = file.path(tempdir(), "ruminate.test")
+
+
 # Making sure that the deployed object is created
 if(!exists("deployed")){
   deployed = FALSE
@@ -86,16 +90,6 @@ tags$li( "If you run into any problems, have questions, or want a feature please
         tags$a("issues", href=issue_url)," page")
 )
 
-ftmptest = file.path(tempdir(), "ruminate.test")
-
-# If the ftmptest file is present we load the development modules
-if(run_dev){
-  dev_modules = shinydashboard::menuItem("Models",          
-                                         tabName = "model",       
-                                         icon    = icon("trowel-bricks"))
-}else {
-  dev_modules = NULL
-}
 
 ui <- shinydashboard::dashboardPage(
   skin="black",
@@ -108,8 +102,6 @@ ui <- shinydashboard::dashboardPage(
        shinydashboard::menuItem("Transform Data", tabName="wrangle", icon=icon("shuffle")),
        shinydashboard::menuItem("Visualize",      tabName="plot",    icon=icon("chart-line")),
        shinydashboard::menuItem("NCA",            tabName="nca",     icon=icon("chart-area")),
-       dev_modules,
-      #shinydashboard::menuItem("Models",         tabName="model",   icon=icon("trowel-bricks")),
        shinydashboard::menuItem("App Info",       tabName="sysinfo", icon=icon("book-medical"))
      )
   ),
@@ -124,12 +116,6 @@ ui <- shinydashboard::dashboardPage(
                column(width=12,
                htmlOutput(NS("NCA",  "NCA_ui_compact")))))
                ),
-       shinydashboard::tabItem(tabName="model",
-               shinydashboard::box(title="Build PK/PD Models", width=12,
-               fluidRow( 
-               column(width=12,
-               htmlOutput(NS("MB",  "MB_ui_compact")))))
-               ),
        shinydashboard::tabItem(tabName="loadsave",
          #     shinydashboard::box(title=NULL, width=12,
                shinydashboard::tabBox(
@@ -233,10 +219,6 @@ server <- function(input, output, session) {
       id_DW  = "DW",
       id_ASM = "ASM"
     )
-    MB_test_mksession(
-      session,
-      full_session=TRUE
-    )
   }
 
   # Module servers
@@ -270,12 +252,6 @@ server <- function(input, output, session) {
                        MOD_yaml_file    = NCA.yaml,
                        FM_yaml_file     = formods.yaml)
 
-  ruminate::MB_Server(id="MB", id_ASM = "ASM", 
-                      deployed         = deployed,
-                      react_state      = react_FM,
-                      MOD_yaml_file    = MB.yaml,
-                      FM_yaml_file     = formods.yaml)
-
 }
 
 shinyApp(ui, server)
